package ch.zhaw.projekt2.turnierverwaltung;

import javafx.collections.FXCollections;
import javafx.collections.ObservableList;

import java.io.Serializable;
import java.util.Arrays;

public class Tournament implements Serializable {
    private String name;
    private Type type;



    public Tournament(String name, Type type) throws InvalidNameException, InvalidTypeException {
        if(!name.matches("[\\w]{1,20}")){
            throw new Tournament.InvalidNameException("Invalid Name entered"); //TODO handle en logging.
        } else if(!Arrays.asList(Type.values()).contains(type)){
            throw new InvalidTypeException("Invalid Type selected"); //TODO handle en logging.
        }

        setName(name);
        setType(type);
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Type getType() {
        return type;
    }

    public void setType(Type type) {
        this.type = type;
    }

    public enum Type {
        KO("KO-System"), GROUPS("Gruppenspiele");

        private String name;

        private Type(String name) {
            this.name = name;
        }

        @Override
        public String toString() {
            return name;
        }

        public static ObservableList<Type> getObservableList(){
            ObservableList<Type> items = FXCollections.observableArrayList();
            items.addAll(values());
            return items;
        }
    }

    public class InvalidNameException extends Exception {
        public InvalidNameException() {
            super();
        }

        public InvalidNameException(String errorMessage) {
            super(errorMessage);
        }

    }

    public class InvalidTypeException extends Exception {
        public InvalidTypeException() {
            super();
        }

        public InvalidTypeException(String errorMessage) {
            super(errorMessage);
        }

    }


}
